.. _utilipy-decorators-funcio:

*****************************************************
Function IO Decorators (`utilipy.decorators.func_io`)
*****************************************************

.. currentmodule:: utilipy.decorators.func_io



Reference/API
=============

.. automodapi:: utilipy.decorators.func_io
